@@ -48,7 +48,7 @@
 class CalcWriterInterface
 {
   public:
-  virtual ~CalcWriterInterface(){};
+  virtual ~CalcWriterInterface();
   virtual void close() = 0;
 
   /**
@@ -132,10 +132,7 @@ class CalcWriterInterface
    * \return OdsTableCellStyleRef pointer on a style reference
    */
   virtual OdsTableCellStyleRef
-  getTableCellStyleRef([[maybe_unused ]] const OdsTableCellStyle &style)
-  {
-    return nullptr;
-  };
+  getTableCellStyleRef([[maybe_unused]] const OdsTableCellStyle &style);
   /**
    * set the cell table style. This is applied to in the stream to following
    * cells. This ends by using an other style reference or by using
@@ -144,20 +141,14 @@ class CalcWriterInterface
    * \param style_ref OdsTableCellStyleRef
    */
   virtual void
-  setTableCellStyleRef([[maybe_unused ]] OdsTableCellStyleRef style_ref)
-  {
-  };
+  setTableCellStyleRef([[maybe_unused]] OdsTableCellStyleRef style_ref);
 
   /**
    * clear cell style definition in the stream. the default style will be
    * applied.
    *
    */
-  void
-  clearTableCellStyleRef()
-  {
-    setTableCellStyleRef(nullptr);
-  };
+  void clearTableCellStyleRef();
 
   /**
    * \brief set annotation to write in the next cell
@@ -168,9 +159,8 @@ class CalcWriterInterface
   /** \brief apply solor scale conditional format on a cell range
    *
    */
-  virtual void addColorScale([[maybe_unused ]] const OdsColorScale &ods_color_scale)
-	{
-	};
+  virtual void
+  addColorScale([[maybe_unused]] const OdsColorScale &ods_color_scale);
 
   /** @brief get the last written cell coordinate in ODS coordinate format
    * get the coordinate of the last written cell or an empty string if the
@@ -178,16 +168,16 @@ class CalcWriterInterface
    *
    * @return QString with ODS cell coordinate of the form : "classeur.A5"
    */
-  virtual QString
-  getOdsCellCoordinate()
-  {
-    return QString();
-  };
+  virtual QString getOdsCellCoordinate();
 
   /** @brief set ODS table settings of the current sheet (table)
    */
-  virtual void setCurrentOdsTableSettings([[maybe_unused ]] const OdsTableSettings &settings)
-	{
-	};
-};
+  virtual void
+  setCurrentOdsTableSettings([[maybe_unused]] const OdsTableSettings &settings);
 
+  /**
+   * \brief write a cell for a given QVariant
+   * \param QVariant variable to write
+   */
+  virtual void writeCellVariant(const QVariant &var);
+};
