@@ -220,13 +220,15 @@ OdsCell::setValueOfUndefinedType(const QString &value)
           return;
         }
     }
-  if(_string_value == "T")
+  if((_string_value == "T") || (_string_value == "TRUE") ||
+     (_string_value == "VRAI"))
     {
       _bool_value        = true;
       _office_value_type = "boolean";
       return;
     }
-  if(_string_value == "F")
+  if((_string_value == "F") || (_string_value == "FALSE") ||
+     (_string_value == "FAUX"))
     {
       _bool_value        = false;
       _office_value_type = "boolean";
