@@ -22,12 +22,12 @@
 #include <QString>
 #include <QDateTime>
 //#include <QDebug>
-class SaxHandlerContentXml;
+class QXmlStreamReaderContentXml;
 class TsvReader;
 
 class OdsCell
 {
-  friend SaxHandlerContentXml;
+  friend QXmlStreamReaderContentXml;
   friend TsvReader;
 
   public:
@@ -61,6 +61,3 @@ class OdsCell
   bool _bool_value;
   bool _is_empty;
 };
-
-
-
