@@ -71,20 +71,20 @@ TsvDirectoryWriter::setSeparator(TsvSeparator separator)
 void
 TsvDirectoryWriter::close()
 {
-  if(_p_otxtstream != nullptr)
+  if(mpa_otxtstream != nullptr)
     {
-      *_p_otxtstream << _end_of_line;
-      _p_otxtstream->flush();
+      *mpa_otxtstream << _end_of_line;
+      mpa_otxtstream->flush();
       //_p_otxtstream->close();
-      delete(_p_otxtstream);
-      _p_otxtstream = nullptr;
+      delete(mpa_otxtstream);
+      mpa_otxtstream = nullptr;
     }
-  if(_p_ofile != nullptr)
+  if(mpa_ofile != nullptr)
     {
-      _p_ofile->flush();
-      _p_ofile->close();
-      delete(_p_ofile);
-      _p_ofile = nullptr;
+      mpa_ofile->flush();
+      mpa_ofile->close();
+      delete(mpa_ofile);
+      mpa_ofile = nullptr;
     }
 }
 
@@ -94,21 +94,28 @@ TsvDirectoryWriter::writeSheet(const QString &sheetName)
   close();
   // qDebug() << " TsvDirectoryWriter::writeSheet " <<
   // _directory.absolutePath();
-  _p_ofile = new QFile(QString(_directory.absolutePath())
-                         .append("/")
-                         .append(sheetName)
-                         .append(this->_file_extension));
+  mpa_ofile = new QFile(QString(_directory.absolutePath())
+                          .append("/")
+                          .append(sheetName)
+                          .append(this->_file_extension));
   // qDebug() << " TsvDirectoryWriter::writeSheet " <<
   // QFileInfo(*_p_ofile).absoluteFilePath();
-  if(_p_ofile->open(QIODevice::WriteOnly))
+  if(mpa_ofile->open(QIODevice::WriteOnly))
     {
-      _p_otxtstream = new QTextStream(_p_ofile);
+      mpa_otxtstream = new QTextStream(mpa_ofile);
     }
   else
     {
       throw OdsException(QString("unable to write into file %1")
-                           .arg(QFileInfo(*_p_ofile).absoluteFilePath()));
+                           .arg(QFileInfo(*mpa_ofile).absoluteFilePath()));
     }
+  initializeSheet();
+}
+
+void
+TsvDirectoryWriter::initializeSheet()
+{
+
   _tableRowStart = true;
   _startingSheet = true;
 }
@@ -117,7 +124,7 @@ TsvDirectoryWriter::writeSheet(const QString &sheetName)
 void
 TsvDirectoryWriter::ensureSheet()
 {
-  if(_p_otxtstream == nullptr)
+  if(mpa_otxtstream == nullptr)
     {
       writeSheet("default");
     }
@@ -132,13 +139,13 @@ TsvDirectoryWriter::writeLine()
     }
   else
     {
-      *_p_otxtstream << _end_of_line;
+      *mpa_otxtstream << _end_of_line;
     }
   _startingSheet = false;
   _tableRowStart = true;
 
   if(m_flushLines)
-    _p_otxtstream->flush();
+    mpa_otxtstream->flush();
 }
 void
 TsvDirectoryWriter::writeCell(const char *cstr)
@@ -151,13 +158,13 @@ TsvDirectoryWriter::writeCell(const QString &text)
   ensureSheet();
   if(!_tableRowStart)
     {
-      *_p_otxtstream << m_separator;
+      *mpa_otxtstream << m_separator;
     }
   _tableRowStart = false;
 
   if(m_quoteStrings)
     {
-      *_p_otxtstream << QString("\"%1\"").arg(
+      *mpa_otxtstream << QString("\"%1\"").arg(
         QString(text).replace("\"", "\"\""));
     }
   else
@@ -165,12 +172,12 @@ TsvDirectoryWriter::writeCell(const QString &text)
       if(text.contains(_end_of_line) || text.contains(m_separator) ||
          text.contains("\""))
         {
-          *_p_otxtstream << QString("\"%1\"").arg(
+          *mpa_otxtstream << QString("\"%1\"").arg(
             QString(text).replace("\"", "\"\""));
         }
       else
         {
-          *_p_otxtstream << text;
+          *mpa_otxtstream << text;
         }
     }
 
@@ -183,10 +190,10 @@ TsvDirectoryWriter::writeRawCell(const QString &text)
   ensureSheet();
   if(!_tableRowStart)
     {
-      *_p_otxtstream << m_separator;
+      *mpa_otxtstream << m_separator;
     }
   _tableRowStart = false;
-  *_p_otxtstream << text;
+  *mpa_otxtstream << text;
   _startingSheet = false;
 }
 void
@@ -195,7 +202,7 @@ TsvDirectoryWriter::writeEmptyCell()
   ensureSheet();
   if(!_tableRowStart)
     {
-      *_p_otxtstream << m_separator;
+      *mpa_otxtstream << m_separator;
     }
   _tableRowStart = false;
   _startingSheet = false;
@@ -203,7 +210,7 @@ TsvDirectoryWriter::writeEmptyCell()
 void
 TsvDirectoryWriter::writeCell(std::size_t num)
 {
-  writeCell(QString::number(num, 'g', 10));
+  writeRawCell(QString::number(num, 'g', 10));
 }
 void
 TsvDirectoryWriter::writeCell(int num)
