@@ -36,9 +36,9 @@ class TsvDirectoryWriter : public CalcWriterInterface
   virtual ~TsvDirectoryWriter();
 
 
-  void close() override;
+  virtual void close() override;
 
-  void writeSheet(const QString &sheetName) override;
+  virtual void writeSheet(const QString &sheetName) override;
   void writeLine() override;
   void writeCell(const char *) override;
   void writeCell(const QString &) override;
@@ -97,10 +97,12 @@ class TsvDirectoryWriter : public CalcWriterInterface
   protected:
   TsvDirectoryWriter();
   void writeRawCell(const QString &text);
+  void initializeSheet();
 
+  protected:
   QString m_separator            = "\t";
   QString _end_of_line           = "\n";
-  QTextStream *_p_otxtstream     = nullptr;
+  QTextStream *mpa_otxtstream    = nullptr;
   unsigned int numFloatPrecision = 12;
 
   private:
@@ -108,12 +110,12 @@ class TsvDirectoryWriter : public CalcWriterInterface
 
   QString _file_extension = ".tsv";
 
+  bool m_quoteStrings             = false;
+  bool m_flushLines               = false;
+  TsvSeparator m_tsvSeparatorEnum = TsvSeparator::tab;
+  void ensureSheet();
   bool _tableRowStart = true;
   bool _startingSheet = false;
-  bool m_quoteStrings = false;
-  bool m_flushLines   = false;
-  TsvSeparator m_tsvSeparatorEnum = TsvSeparator::tab;
 
-  QFile *_p_ofile = nullptr;
-  void ensureSheet();
+  QFile *mpa_ofile = nullptr;
 };
