@@ -21,19 +21,19 @@
 
 TsvOutputStream::TsvOutputStream(QTextStream &otxtstream) : TsvDirectoryWriter()
 {
-  _p_otxtstream = &otxtstream;
+  mpa_otxtstream = &otxtstream;
 }
 
 TsvOutputStream::~TsvOutputStream()
 {
   // close();
-  _p_otxtstream = nullptr;
+  mpa_otxtstream = nullptr;
 }
 
 void
 TsvOutputStream::close()
 {
-  _p_otxtstream->flush();
+  mpa_otxtstream->flush();
 }
 
 void
@@ -47,6 +47,6 @@ TsvOutputStream::writeSheet(const QString &sheetName)
 {
   if(_no_sheet_name)
     return;
-  *_p_otxtstream << _end_of_line << _end_of_line << "**** " << sheetName
-                 << " ****" << _end_of_line;
+  *mpa_otxtstream << _end_of_line << _end_of_line << "**** " << sheetName
+                  << " ****" << _end_of_line;
 }
