@@ -20,7 +20,7 @@
 #include "manifestxml.h"
 #include <QXmlStreamWriter>
 
-#include <quazip5/quazipfile.h>
+#include <quazipfile.h>
 
 QString ManifestXml::_namespaceURI =
   "urn:oasis:names:tc:opendocument:xmlns:manifest:1.0";
