@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include <quazip5/quazip.h>
+#include <quazip.h>
 #include <QXmlStreamWriter>
 
 class ManifestXml
