@@ -75,7 +75,7 @@ ZipTsvOutputStream::close()
 {
 
   qDebug();
-  
+
   TsvDirectoryWriter::close();
   closeCurrentZipSheet();
   if(mpa_quaZip != nullptr)
@@ -104,6 +104,10 @@ ZipTsvOutputStream::closeCurrentZipSheet()
   if(mpa_outFileInZip != nullptr)
     {
       qDebug();
+      if(mpa_otxtstream != nullptr)
+        {
+          mpa_otxtstream->flush();
+        }
       mpa_outFileInZip->close();
       qDebug();
       delete mpa_outFileInZip;
